@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Iterator::Rule;
 # ABSTRACT: Iterative, recursive file finder
-our $VERSION = '1.010';
+our $VERSION = '1.011';
 
 # Register warnings category
 use warnings::register;
@@ -159,6 +159,11 @@ sub _iter {
     my $has_rules           = @{ $self->{rules} };
     my $stash               = {};
 
+    my $opt_report_symlinks =
+      defined( $opts{report_symlinks} )
+      ? $opts{report_symlinks}
+      : $opts{follow_symlinks};
+
     # if not subclassed, we want to inline
     my $can_children = $self->can("_children");
 
@@ -177,12 +182,15 @@ sub _iter {
             return unless $item;
             return $item->[0] if ref $item eq 'ARRAY'; # deferred for postorder
             my $string_item = $opt_stringify ? "$item" : $item;
-            if ( !$opt_follow_symlinks ) {
-                redo LOOP if -l $string_item;
-            }
 
             # by default, we're interested in everything and prune nothing
             my ( $interest, $prune ) = ( 1, 0 );
+
+            if ( -l $string_item ) {
+                $prune = 1 if !$opt_follow_symlinks;
+                redo LOOP if !$opt_report_symlinks;
+            }
+
             if ($has_rules) {
                 local $_ = $item;
                 $stash->{_depth} = $depth;
@@ -718,7 +726,7 @@ Path::Iterator::Rule - Iterative, recursive file finder
 
 =head1 VERSION
 
-version 1.010
+version 1.011
 
 =head1 SYNOPSIS
 
@@ -843,6 +851,10 @@ C<follow_symlinks> -- Follow directory symlinks when true. Default is 1.
 
 =item *
 
+C<report_symlinks> -- Includes symlinks in results when true. Default is equal to C<follow_symlinks>.
+
+=item *
+
 C<loop_safe> -- Prevents visiting the same directory more than once when true.  Default is 1.
 
 =item *
@@ -863,7 +875,12 @@ Filesystem loops might exist from either hard or soft links.  The C<loop_safe>
 option prevents infinite loops, but adds some overhead by making C<stat> calls.
 Because directories are visited only once when C<loop_safe> is true, matches
 could come from a symlinked directory before the real directory depending on
-the search order.  To get only the real files, turn off C<follow_symlinks>.
+the search order.
+
+To get only the real files, turn off C<follow_symlinks>.  You can have
+symlinks included in results, but not descend into symlink directories if
+you turn off C<follow_symlinks>, but turn on C<report_symlinks>.
+
 Turning C<loop_safe> off and leaving C<follow_symlinks> on avoids C<stat> calls
 and will be fastest, but with the risk of an infinite loop and repeated files.
 The default is slow, but safe.
